pub struct ValMatchV1<'a> { /* private fields */ }Expand description
ValMatchV1 endpoints handle, accessed by calling val_match_v1() on a RiotApi instance.
Riot Developer API Reference
Note: this struct is automatically generated.
Implementations
Sourceimpl<'a> ValMatchV1<'a>
impl<'a> ValMatchV1<'a>
Sourcepub fn get_match(
&self,
route: ValPlatformRoute,
match_id: &str,
) -> impl Future<Output = Result<Option<Match>>> + 'a
pub fn get_match( &self, route: ValPlatformRoute, match_id: &str, ) -> impl Future<Output = Result<Option<Match>>> + 'a
Sourcepub fn try_get_match(
&self,
min_capacity: f32,
route: ValPlatformRoute,
match_id: &str,
) -> impl Future<Output = TryRequestResult<Option<Match>>> + 'a
pub fn try_get_match( &self, min_capacity: f32, route: ValPlatformRoute, match_id: &str, ) -> impl Future<Output = TryRequestResult<Option<Match>>> + 'a
Variation that checks for minimum capacity before making the request, returning None if insufficent capacity
See get_match for detailed documentation
Parameters
min_capacity- Minimum capacity required as a float from 1.0 (all capacity) to 0.0 (no capacity) excluding burstroute- Route to query.match_id(required, in path)
Riot Developer API Reference
Note: this method is automatically generated.
Sourcepub fn get_matchlist(
&self,
route: ValPlatformRoute,
puuid: &str,
) -> impl Future<Output = Result<Matchlist>> + 'a
pub fn get_matchlist( &self, route: ValPlatformRoute, puuid: &str, ) -> impl Future<Output = Result<Matchlist>> + 'a
Sourcepub fn try_get_matchlist(
&self,
min_capacity: f32,
route: ValPlatformRoute,
puuid: &str,
) -> impl Future<Output = TryRequestResult<Matchlist>> + 'a
pub fn try_get_matchlist( &self, min_capacity: f32, route: ValPlatformRoute, puuid: &str, ) -> impl Future<Output = TryRequestResult<Matchlist>> + 'a
Variation that checks for minimum capacity before making the request, returning None if insufficent capacity
See get_matchlist for detailed documentation
Parameters
min_capacity- Minimum capacity required as a float from 1.0 (all capacity) to 0.0 (no capacity) excluding burstroute- Route to query.puuid(required, in path)
Riot Developer API Reference
Note: this method is automatically generated.
Sourcepub fn get_recent(
&self,
route: ValPlatformRoute,
queue: &str,
) -> impl Future<Output = Result<RecentMatches>> + 'a
pub fn get_recent( &self, route: ValPlatformRoute, queue: &str, ) -> impl Future<Output = Result<RecentMatches>> + 'a
Get recent matches
Implementation Notes
Returns a list of match ids that have completed in the last 10 minutes for live regions and 12 hours for the esports routing value. NA/LATAM/BR share a match history deployment. As such, recent matches will return a combined list of matches from those three regions. Requests are load balanced so you may see some inconsistencies as matches are added/removed from the list.
Parameters
route- Route to query.queue(required, in path)
Riot Developer API Reference
Note: this method is automatically generated.
Sourcepub fn try_get_recent(
&self,
min_capacity: f32,
route: ValPlatformRoute,
queue: &str,
) -> impl Future<Output = TryRequestResult<RecentMatches>> + 'a
pub fn try_get_recent( &self, min_capacity: f32, route: ValPlatformRoute, queue: &str, ) -> impl Future<Output = TryRequestResult<RecentMatches>> + 'a
Variation that checks for minimum capacity before making the request, returning None if insufficent capacity
See get_recent for detailed documentation
Parameters
min_capacity- Minimum capacity required as a float from 1.0 (all capacity) to 0.0 (no capacity) excluding burstroute- Route to query.queue(required, in path)
Riot Developer API Reference
Note: this method is automatically generated.